@@ -16,8 +16,8 @@ logger = logging.getLogger(__name__)
 MERGE_METHODS = ('first', 'last', 'min', 'max')
 
 
-def merge(datasets, bounds=None, res=None, nodata=None, precision=10, indexes=None,
-          method='first'):
+def merge(datasets, bounds=None, res=None, nodata=None, dtype=None, precision=10,
+          indexes=None, output_count=None, method='first'):
     """Copy valid pixels from input files to an output file.
 
     All files must have the same number of bands, data type, and
@@ -45,10 +45,16 @@ def merge(datasets, bounds=None, res=None, nodata=None, precision=10, indexes=No
     nodata: float, optional
         nodata value to use in output file. If not set, uses the nodata value
         in the first input raster.
+    dtype: numpy dtype or string
+        dtype to use in outputfile. If not set, uses the dtype value in the
+        first input raster.
     precision: float, optional
         Number of decimal points of precision when computing inverse transform.
     indexes : list of ints or a single int, optional
         bands to read and merge
+    output_count: int, optional
+        If using callable it may be useful to have additional bands in the output
+        in addition to the indexes specified for read
     method : str or callable
         pre-defined method:
             first: reverse painting
@@ -57,7 +63,7 @@ def merge(datasets, bounds=None, res=None, nodata=None, precision=10, indexes=No
             max: pixel-wise max of existing and new
         or custom callable with signature:
 
-        def function(old_data, new_data, old_nodata, new_nodata):
+        def function(old_data, new_data, old_nodata, new_nodata, index=None, roff=None, coff=None):
 
             Parameters
             ----------
@@ -69,6 +75,12 @@ def merge(datasets, bounds=None, res=None, nodata=None, precision=10, indexes=No
             old_nodata, new_data : array_like
                 boolean masks where old/new data is nodata
                 same shape as old_data
+            index: int
+                index of the current dataset within the merged dataset collection
+            roff: int
+                row offset in base array
+            coff: int
+                column offset in base array
 
     Returns
     -------
@@ -86,7 +98,7 @@ def merge(datasets, bounds=None, res=None, nodata=None, precision=10, indexes=No
     first = datasets[0]
     first_res = first.res
     nodataval = first.nodatavals[0]
-    dtype = first.dtypes[0]
+    dt = first.dtypes[0]
 
     if method not in MERGE_METHODS and not callable(method):
         raise ValueError('Unknown method {0}, must be one of {1} or callable'
@@ -94,11 +106,14 @@ def merge(datasets, bounds=None, res=None, nodata=None, precision=10, indexes=No
 
     # Determine output band count
     if indexes is None:
-        output_count = first.count
+        src_count = first.count
     elif isinstance(indexes, int):
-        output_count = 1
+        src_count = indexes
     else:
-        output_count = len(indexes)
+        src_count = len(indexes)
+
+    if not output_count:
+        output_count = src_count
 
     # Extent from option or extent of all inputs
     if bounds:
@@ -137,8 +152,12 @@ def merge(datasets, bounds=None, res=None, nodata=None, precision=10, indexes=No
     logger.debug("Output width: %d, height: %d", output_width, output_height)
     logger.debug("Adjusted bounds: %r", (dst_w, dst_s, dst_e, dst_n))
 
+    if dtype is not None:
+        dt = dtype
+        logger.debug("Set dtype: %s", dt)
+
     # create destination array
-    dest = np.zeros((output_count, output_height, output_width), dtype=dtype)
+    dest = np.zeros((output_count, output_height, output_width), dtype=dt)
 
     if nodata is not None:
         nodataval = nodata
@@ -168,17 +187,17 @@ def merge(datasets, bounds=None, res=None, nodata=None, precision=10, indexes=No
         nodataval = 0
 
     if method == 'first':
-        def copyto(old_data, new_data, old_nodata, new_nodata):
+        def copyto(old_data, new_data, old_nodata, new_nodata, **kwargs):
             mask = np.logical_and(old_nodata, ~new_nodata)
             old_data[mask] = new_data[mask]
 
     elif method == 'last':
-        def copyto(old_data, new_data, old_nodata, new_nodata):
+        def copyto(old_data, new_data, old_nodata, new_nodata, **kwargs):
             mask = ~new_nodata
             old_data[mask] = new_data[mask]
 
     elif method == 'min':
-        def copyto(old_data, new_data, old_nodata, new_nodata):
+        def copyto(old_data, new_data, old_nodata, new_nodata, **kwargs):
             mask = np.logical_and(~old_nodata, ~new_nodata)
             old_data[mask] = np.minimum(old_data[mask], new_data[mask])
 
@@ -186,7 +205,7 @@ def merge(datasets, bounds=None, res=None, nodata=None, precision=10, indexes=No
             old_data[mask] = new_data[mask]
 
     elif method == 'max':
-        def copyto(old_data, new_data, old_nodata, new_nodata):
+        def copyto(old_data, new_data, old_nodata, new_nodata, **kwargs):
             mask = np.logical_and(~old_nodata, ~new_nodata)
             old_data[mask] = np.maximum(old_data[mask], new_data[mask])
 
@@ -199,7 +218,7 @@ def merge(datasets, bounds=None, res=None, nodata=None, precision=10, indexes=No
     else:
         raise ValueError(method)
 
-    for src in datasets:
+    for idx, src in enumerate(datasets):
         # Real World (tm) use of boundless reads.
         # This approach uses the maximum amount of memory to solve the
         # problem. Making it more efficient is a TODO.
@@ -226,7 +245,7 @@ def merge(datasets, bounds=None, res=None, nodata=None, precision=10, indexes=No
         # 4. Read data in source window into temp
         trows, tcols = (
             int(round(dst_window.height)), int(round(dst_window.width)))
-        temp_shape = (output_count, trows, tcols)
+        temp_shape = (src_count, trows, tcols)
         temp = src.read(out_shape=temp_shape, window=src_window,
                         boundless=False, masked=True, indexes=indexes)
 
@@ -242,6 +261,7 @@ def merge(datasets, bounds=None, res=None, nodata=None, precision=10, indexes=No
             region_nodata = region == nodataval
             temp_nodata = temp.mask
 
-        copyto(region, temp, region_nodata, temp_nodata)
+        copyto(region, temp, region_nodata, temp_nodata,
+               index=idx, roff=roff, coff=coff)
 
     return dest, output_transform
