@@ -204,7 +204,6 @@ def test_env_defaults(gdalenv):
     assert env.options['foo'] == 'x'
     assert not env.context_options
     with env:
-        assert get_gdal_config('CHECK_WITH_INVERT_PROJ') is True
         assert get_gdal_config('GTIFF_IMPLICIT_JPEG_OVR') is False
         assert get_gdal_config("RASTERIO_ENV") is True
 
@@ -781,6 +780,7 @@ def test_require_gdal_version_chaining():
     assert message in exc_info.value.args[0]
 
 
+@pytest.mark.network
 def test_rio_env_no_credentials(tmpdir, monkeypatch, runner):
     """Confirm that we can get drivers without any credentials"""
     credentials_file = tmpdir.join('credentials')
@@ -791,9 +791,13 @@ aws_access_key_id = bar
 """)
     monkeypatch.setenv('AWS_SHARED_CREDENTIALS_FILE', str(credentials_file))
     monkeypatch.delenv('AWS_ACCESS_KEY_ID', raising=False)
-    # Assert that we don't have any AWS credentials by accident.
-    with pytest.raises(Exception):
-        rasterio.open("s3://mapbox/rasterio/RGB.byte.tif")
+
+    # To verify that we're unauthenticated, we make a request for an known existing object that will return 404 Not Found.
+    with pytest.raises(Exception) as exc_info:
+        s3 = boto3.client("s3")
+        s3.head_object(Bucket="landsat-pds", Key="L8/139/045/LC81390452014295LGN00/LC81390452014295LGN00_B1.TIF")
+
+    assert exc_info.value.response["Error"]["Code"] == "403"
 
     with rasterio.Env() as env:
         assert env.drivers()
